# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define named_version 1.0-beta-2

Name:           jsr275
Version:        1.0
Release:        0.b2.1%{?dist}
Summary:        Java Units of Measure

Group:          Development/Libraries
License:        BSD
URL:            https://jsr-275.dev.java.net

Source0:        jsr275-1.0.tgz
#  cvs -d :pserver:guest@cvs.dev.java.net:/cvs login
#  cvs -d :pserver:guest@cvs.dev.java.net:/cvs export -r v1-0 -d jsr275-1.0 jsr-275
# tar czf jsr275-1.0.tgz jsr275-1.0/

Source1:       %{name}-settings.xml
Source2:       %{name}-jpp-depmap.xml 
Source3:       http://download.java.net/maven/2/net/java/dev/jsr-275/jsr-275/1.0-beta-2/jsr-275-1.0-beta-2-sources.jar
Source4:       http://download.java.net/maven/2/net/java/dev/jsr-275/jsr-275/1.0-beta-2/jsr-275-1.0-beta-2.pom
Patch0:        jsr275-pom.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  maven2 >= 2.0.8
BuildRequires:  apache-commons-parent
BuildRequires:  colapi

Requires:  java >= 1.6.0
Requires:  jpackage-utils >= 0:1.7.5

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

BuildArch:      noarch

%description
Units of Measure API specifies one or more Java packages for
the programmatic handling of physical quantities and their 
expression as numbers of units. The specification includes:
* Interfaces and abstract classes with methods for unit 
  operations:
  o Checking of unit compatibility
  o Expression of a quantity in various units
  o Arithmetic operations on units
  o Concrete classes implementing the standard types of units 
    (such as base, supplementary, and derived) and unit 
    conversions.
* Classes for parsing unit specifications in string form and 
  for formatting string representations of quantities.
* A database of predefined units.
Developers frequently encounter the need to model units of 
measure, because objects in the real world are subject to 
these measures. When working with units, developers need to 
understand the mathematics of units, how to convert between 
systems, and how to format and parse string representations 
of units. Most of this work can be consolidated into one or 
two Java packages, which is a primary aim of this JSR. This 
package will help developers create safe, correct software 
to deal with common problem of modeling units.

%package javadoc 
Summary:        Javadocs for %{name} 
Group:          Documentation 
Requires:       %{name} = %{version}-%{release} 
 
%description javadoc 
%{summary}. 

%prep
%setup -q 
cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
%patch0 -b .sav
pushd src/main/java
rm -rf *
jar xf %{SOURCE3}
popd
rm -rf src/test
cp %{SOURCE4} pom.xml
mkdir external_repo
ln -s %{_javadir} external_repo/JPP

%build
export LANG=en_US.UTF-8
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Djava.awt.headless=true -Daggregate=true"
%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        install 

%{_bindir}/mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        javadoc:javadoc

%install
%__rm -rf %{buildroot}

# jar
%__mkdir_p %{buildroot}%{_javadir}
%__install -m 644 target/jsr-275-%{named_version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do \
%__ln_s ${jar} ${jar/-%{version}/}; done)

# poms
%__mkdir_p %{buildroot}%{_datadir}/maven2/poms
%__install -m 644 pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap javax.measure jsr-275 %{named_version} JPP %{name}

# javadoc 
%__mkdir_p %{buildroot}%{_javadocdir}/%{name}-%{version} 
%__cp -a target/site/apidocs/* \
               %{buildroot}%{_javadocdir}/%{name}-%{version}/
%__ln_s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name} 

%clean
%__rm -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%{_javadir}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc 
%defattr(-,root,root,-) 
%{_javadocdir}/%{name}-%{version} 
%{_javadocdir}/%{name} 

%changelog
* Mon Oct 18 2010 Ralph Apel <r.apel@r-apel.de> 1.0-0.b2.1
- 1.0-b2 is required by geotools 2.6 - 2.7

* Thu Oct 14 2010 Ralph Apel <r.apel@r-apel.de> 0.9.4-1
- First release

